import { createElement, useState, useEffect, memo, useCallback } from 'react';
import hljs from 'highlight.js';
import prettyBytes from 'pretty-bytes';
import classNames from 'classnames';

var styles = {"container":"_1Lxpd","header":"_1aDvk","body":"_2mo3X","num":"_1H33u","code":"_1NqbF","codeInner":"_2Dc72","highlighted":"_CLeTf"};

var NumberCell = (function (_ref) {
  var lineNumber = _ref.lineNumber,
      onClick = _ref.onClick;
  return createElement("td", {
    id: "L" + lineNumber,
    key: "col-line-number-" + lineNumber,
    "data-line-number": lineNumber,
    className: styles.num,
    onClick: onClick
  });
});

var CodeCell = (function (_ref) {
  var lineNumber = _ref.lineNumber,
      code = _ref.code,
      isHighlight = _ref.isHighlight;

  var _React$useState = useState(styles.code + " " + styles.codeInner),
      className = _React$useState[0],
      setClassName = _React$useState[1];

  useEffect(function () {
    var _classNames;

    setClassName(classNames(styles.code, styles.codeInner, (_classNames = {}, _classNames[styles.highlighted] = isHighlight, _classNames)));
  }, [isHighlight]);
  return createElement("td", {
    id: "LC" + lineNumber,
    key: "col-code-" + lineNumber,
    className: className,
    dangerouslySetInnerHTML: {
      __html: code
    }
  });
});

var Row = (function (_ref) {
  var row = _ref.row,
      showLineNumber = _ref.showLineNumber,
      onLineNumberClick = _ref.onLineNumberClick;
  var lineNumber = row.lineNumber;

  var handleClick = function handleClick(event) {
    onLineNumberClick && onLineNumberClick(lineNumber, event);
  };

  return createElement("tr", null, showLineNumber && createElement(NumberCell, {
    lineNumber: lineNumber,
    onClick: handleClick
  }), createElement(CodeCell, {
    lineNumber: lineNumber,
    code: row.content,
    isHighlight: row.isHighlight
  }));
});

var CodeContainer = memo(function (_ref) {
  var code = _ref.code,
      language = _ref.language,
      _ref$showLineNumber = _ref.showLineNumber,
      showLineNumber = _ref$showLineNumber === void 0 ? true : _ref$showLineNumber,
      _ref$selectedLines = _ref.selectedLines,
      selectedLines = _ref$selectedLines === void 0 ? [] : _ref$selectedLines,
      onLineNumberClick = _ref.onLineNumberClick,
      onUnSelect = _ref.onUnSelect;

  var _React$useState = useState([]),
      lines = _React$useState[0],
      setLines = _React$useState[1];

  useEffect(function () {
    if (selectedLines) {
      setLines(selectedLines);
    }
  }, [selectedLines]);
  var handleUnSelect = useCallback(function (event) {
    if (event.key === 'Escape') {
      setLines([]);
      onUnSelect && onUnSelect();
    }
  }, []);
  useEffect(function () {
    document.body.addEventListener('keydown', handleUnSelect);
  }, []);
  var getSloc = useCallback(function () {
    return code.split('\n').filter(function (line) {
      return line.trim().length > 0;
    }).length;
  }, [code]);
  var getSize = useCallback(function () {
    return prettyBytes(new Blob([code]).size);
  }, [code]);
  var rows = codeToRows(code, language, lines);

  var onClickNum = function onClickNum(lineNumber, event) {
    var highlightedLines = rows.filter(function (row) {
      return row.isHighlight;
    });
    var tmpLines = [];

    if (event.shiftKey) {
      var firstSelectedLine = highlightedLines[0];
      var range = firstSelectedLine.lineNumber - lineNumber;
      tmpLines.push(lineNumber);
      var n = 0;

      while (n <= Math.abs(range)) {
        var index = range > 0 ? lineNumber + n : lineNumber - n;
        tmpLines.push(rows[index - 1].lineNumber);
        n++;
      }
    } else {
      tmpLines.push(lineNumber);
    }

    setLines(tmpLines);
    onLineNumberClick && onLineNumberClick(lineNumber, tmpLines);
  };

  var renderRows = function renderRows() {
    return rows.map(function (row, index) {
      return createElement(Row, {
        key: "code-container-row-" + index,
        row: row,
        showLineNumber: showLineNumber,
        onLineNumberClick: onClickNum
      });
    });
  };

  return createElement("div", {
    className: styles.container
  }, createElement("div", {
    className: styles.header
  }, createElement("div", null, rows.length, " lines (", getSloc(), " sloc) | ", getSize())), createElement("div", {
    className: styles.body + " hljs"
  }, createElement("table", null, createElement("tbody", null, renderRows()))));
});

var codeToRows = function codeToRows(code, language, selectedLines) {
  var highlightedCodes = !!language && hljs.getLanguage(language || '') ? hljs.highlight(language, code).value : hljs.highlightAuto(code).value;
  return highlightedCodes.split('\n').map(function (content, index) {
    return {
      lineNumber: index + 1,
      content: content,
      isHighlight: selectedLines ? !!selectedLines.find(function (lineNumber) {
        return lineNumber === index + 1;
      }) : false
    };
  });
};

export default CodeContainer;
export { CodeContainer };
//# sourceMappingURL=index.modern.js.map
